==> box2d_flame-0.4.1.tar.gz: lib/src/collision/shapes/mass_data.dart <==
/*******************************************************************************
 * Copyright (c) 2015, Daniel Murphy, Google
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *  * Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 ******************************************************************************/

part of box2d;

/** This holds the mass data computed for a shape. */
class MassData {
  /** The mass of the shape, usually in kilograms. */
  double mass = 0.0;
  /** The position of the shape's centroid relative to the shape's origin. */
  final Vector2 center;
  /** The rotational inertia of the shape about the local origin. */
  double I = 0.0;

  /**
   * Blank mass data
   */
  MassData() : this.center = new Vector2.zero();

  /**
   * Copies from the given mass data
   * 
   * @param md
   *            mass data to copy from
   */
  MassData.copy(MassData md)
      : mass = md.mass,
        center = md.center.clone(),
        I = md.I;

  void set(MassData md) {
    mass = md.mass;
    I = md.I;
    center.setFrom(md.center);
  }

  /** Return a copy of this object. */
  MassData clone() {
    return new MassData.copy(this);
  }
}

==> box2d_flame-0.4.5.tar.gz: lib/src/collision/shapes/mass_data.dart <==
/*******************************************************************************
 * Copyright (c) 2015, Daniel Murphy, Google
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *  * Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 ******************************************************************************/

part of box2d;

/** This holds the mass data computed for a shape. */
class MassData {
  /** The mass of the shape, usually in kilograms. */
  double mass = 0.0;
  /** The position of the shape's centroid relative to the shape's origin. */
  final Vector2 center;
  /** The rotational inertia of the shape about the local origin. */
  double I = 0.0;

  /**
   * Blank mass data
   */
  MassData() : this.center = Vector2.zero();

  /**
   * Copies from the given mass data
   * 
   * @param md
   *            mass data to copy from
   */
  MassData.copy(MassData md)
      : mass = md.mass,
        center = md.center.clone(),
        I = md.I;

  void set(MassData md) {
    mass = md.mass;
    I = md.I;
    center.setFrom(md.center);
  }

  /** Return a copy of this object. */
  MassData clone() {
    return MassData.copy(this);
  }
}
